==> odoo_17.0.20251223.zip: odoo-17.0.post20251223/odoo/addons/website_sale_stock/static/tests/tours/website_sale_stock_multilang.js <==
/** @odoo-module **/

import { registry } from "@web/core/registry";

registry.category("web_tour.tours").add('website_sale_stock_multilang', {
    test: true,
    url: '/fr/shop?search=unavailable',
    steps: () => [{
        content: "Open unavailable product page",
        trigger: 'a[content="unavailable_product"]',
    }, {
        content: "Check out of stock message",
        trigger: '#out_of_stock_message:contains("Hors-stock")',
        isCheck: true,
    }, {
        content: "Check price",
        trigger: 'span:contains("123,45")',
        isCheck: true,
    }, {
        content: "Open language selector",
        trigger: '.js_language_selector button',
    }, {
        content: "Switch to English",
        trigger: '.js_change_lang[data-url_code="en"]',
    }, {
        content: "Check out of stock message",
        trigger: '#out_of_stock_message:contains("Out of stock")',
        isCheck: true,
    }, {
        content: "Check price",
        trigger: 'span:contains("123.45")',
        isCheck: true,
    }, {
        content: "Open language selector",
        trigger: '.js_language_selector button',
    }, {
        content: "Switch to French",
        trigger: '.js_change_lang[data-url_code="fr"]',
    }, {
        content: "Check out of stock message",
        trigger: '#out_of_stock_message:contains("Hors-stock")',
        isCheck: true,
    }, {
        content: "Check price",
        trigger: 'span:contains("123,45")',
        isCheck: true,
    }],
});

==> odoo_18.0.20250910.zip: odoo-18.0.post20250910/odoo/addons/website_sale_stock/static/tests/tours/website_sale_stock_multilang.js <==
/** @odoo-module **/

import { registry } from "@web/core/registry";

registry.category("web_tour.tours").add('website_sale_stock_multilang', {
    url: '/fr/shop?search=unavailable',
    steps: () => [{
        content: "Open unavailable product page",
        trigger: 'a[content="unavailable_product"]',
        run: "click",
        expectUnloadPage: true,
    }, {
        content: "Check out of stock message",
        trigger: '#out_of_stock_message:contains("Hors-stock")',
    }, {
        content: "Check price",
        trigger: 'span:contains("123,45")',
    }, {
        content: "Open language selector",
        trigger: '.js_language_selector button',
        run: "click",
    }, {
        content: "Switch to English",
        trigger: '.js_change_lang[data-url_code="en"]',
        run: "click",
        expectUnloadPage: true,
    }, {
        content: "Check out of stock message",
        trigger: '#out_of_stock_message:contains("Out of stock")',
    }, {
        content: "Check price",
        trigger: 'span:contains("123.45")',
    }, {
        content: "Open language selector",
        trigger: '.js_language_selector button',
        run: "click",
    }, {
        content: "Switch to French",
        trigger: '.js_change_lang[data-url_code="fr"]',
        run: "click",
        expectUnloadPage: true,
    }, {
        content: "Check out of stock message",
        trigger: '#out_of_stock_message:contains("Hors-stock")',
    }, {
        content: "Check price",
        trigger: 'span:contains("123,45")',
    }],
});
